Celery Flower
=============

Web based Celery administration and monitoring tool. Screenshots_.

.. _Screenshots: http://www.flickr.com/photos/82180312@N06/7527050620/in/set-72157630477732276/lightbox/

Usage
-----

Launch the server and open http://localhost:8008: ::

    $ flower --port 8008

Or launch from celery: ::

    $ celery flower --port 8008

Installation
------------

To install, simply: ::

    $ pip install flower

